@@ -11,11 +11,13 @@ from xync_schema import models
 from xync_schema.enums import FileType
 from xync_schema.xtype import CurEx, CoinEx, BaseAd, BaseAdIn
 
+from xync_client.Abc.AdLoader import AdLoader
 from xync_client.Abc.xtype import PmEx, MapOfIdsList
 from xync_client.pm_unifier import PmUnifier, PmUni
 
 
-class BaseExClient(HttpClient):
+class BaseExClient(HttpClient, AdLoader):
+    host: str = None
     cur_map: dict[int, str] = {}
     unifier_class: type = PmUnifier
     logo_pre_url: str
@@ -33,7 +35,7 @@ class BaseExClient(HttpClient):
     ):
         self.ex = ex
         self.bot = bot
-        super().__init__(getattr(ex, attr), headers, cookies, proxy and proxy.str())
+        super().__init__(self.host or getattr(ex, attr), headers, cookies, proxy and proxy.str())
 
     @abstractmethod
     def pm_type_map(self, typ: models.PmEx) -> str: ...
@@ -72,6 +74,7 @@ class BaseExClient(HttpClient):
         pm_exids: list[str | int] = None,
         amount: int = None,
         lim: int = None,
+        vm_filter: bool = False,
     ) -> list[BaseAd]:  # {ad.id: ad}
         ...
 
@@ -250,14 +253,14 @@ class BaseExClient(HttpClient):
         return True
 
     # Сохранение чужого объявления (с Pm-ами) в бд
-    async def ad_pydin2db(self, ad_pydin: BaseAdIn) -> models.Ad:
-        dct = ad_pydin.model_dump()
-        dct["exid"] = dct.pop("id")
-        ad_in = models.Ad.validate(dct)
-        ad_db, _ = await models.Ad.update_or_create(**ad_in.df_unq())
-        await ad_db.credexs.add(*getattr(ad_pydin, "credexs_", []))
-        await ad_db.pmexs.add(*getattr(ad_pydin, "pmexs_", []))
-        return ad_db
+    # async def ad_pydin2db(self, ad_pydin: BaseAdIn) -> models.Ad:
+    #     dct = ad_pydin.model_dump()
+    #     dct["exid"] = dct.pop("id")
+    #     ad_in = models.Ad.validate(dct)
+    #     ad_db, _ = await models.Ad.update_or_create(**ad_in.df_unq())
+    #     await ad_db.credexs.add(*getattr(ad_pydin, "credexs_", []))
+    #     await ad_db.pmexs.add(*getattr(ad_pydin, "pmexs_", []))
+    #     return ad_db
 
     async def file_upsert(self, url: str, ss: ClientSession = None) -> models.File:
         if not (file := await models.File.get_or_none(name__startswith=url.split("?")[0])):
