@@ -32,7 +32,7 @@ class PmAgentClient(HasAbotUid, metaclass=ABCMeta):
     ubot: FileClient | UserClient = None
     page: Page
     pages: type(StrEnum) = Pages
-    last_active: datetime = datetime.now()
+    last_active: datetime = now()
     with_userbot: bool = False
     _is_started: bool = False
 
