@@ -53,7 +53,9 @@ class BaseOrderReq(BaseModel):
     asset_amount: float | None = None
     fiat_amount: float | None = None
 
-    # todo: mv from to base to special ex class
+    pmex_exid: str = None  # int
+
+    # todo: mv from base to special ex class
     amount_is_fiat: bool = True
     is_sell: bool = None
     cur_exid: int | str = None
