@@ -6,7 +6,7 @@ from xync_schema.models import Ex
 from xync_schema import xtype
 
 from xync_client.Abc.Ex import BaseExClient
-from xync_client.loader import TORM, TOKEN
+from xync_client.loader import TORM, NET_TOKEN
 from xync_client.Abc.xtype import PmEx, MapOfIdsList
 from xync_client.BitGet.etype import ad
 
@@ -94,7 +94,7 @@ class ExClient(BaseExClient):
 async def main():
     _ = await init_db(TORM, True)
     bg = await Ex.get(name="BitGet")
-    cl = ExClient(bg, FileClient(TOKEN))
+    cl = ExClient(bg, FileClient(NET_TOKEN))
     _ads = await cl.ads("USDT", "RUB", False, [])
     await cl.curs()
     await cl.coins()
