@@ -9,6 +9,7 @@ import websockets
 from asyncio import run, sleep
 from decimal import Decimal
 
+from bybit_p2p import P2P
 from playwright.async_api import async_playwright
 from pydantic import ValidationError
 from pyro_client.client.file import FileClient
@@ -16,6 +17,7 @@ from tortoise.exceptions import IntegrityError
 from tortoise.timezone import now
 from tortoise.transactions import in_transaction
 from xync_bot import XyncBot
+from xync_client.Bybit.ex import ExClient
 
 from xync_client.Abc.PmAgent import PmAgentClient
 from xync_schema import models
@@ -32,16 +34,17 @@ from xync_client.Bybit.etype.order import (
 )
 from xync_client.loader import NET_TOKEN, PAY_TOKEN
 from xync_client.Abc.InAgent import BaseInAgentClient
-from xync_client.Bybit.agent import AgentClient
 
 
 class InAgentClient(BaseInAgentClient):
-    agent_client: AgentClient
+    actor: models.Actor
+    api: P2P
+    ex_client: ExClient
 
     async def start_listen(self):
-        t = await self.agent_client.ott()
+        t = await self.ott()
         ts = int(float(t["time_now"]) * 1000)
-        await self.ws_prv(self.agent_client.agent.auth["deviceId"], t["result"], ts)
+        await self.ws_prv(self.actor.agent.auth["deviceId"], t["result"], ts)
 
     # 3N: [T] - Уведомление об одобрении запроса на сделку
     async def request_accepted_notify(self) -> int: ...  # id
@@ -77,7 +80,7 @@ class InAgentClient(BaseInAgentClient):
             while resp := await websocket.recv():
                 if data := json.loads(resp):
                     upd, order_db = None, None
-                    logging.info(f" {datetime.now().strftime('%H:%M:%S')} upd: {data.get('topic')}:{data.get('type')}")
+                    logging.info(f" {now().strftime('%H:%M:%S')} upd: {data.get('topic')}:{data.get('type')}")
                     match data.get("topic"):
                         case "OTC_ORDER_STATUS":
                             match data["type"]:
@@ -87,11 +90,11 @@ class InAgentClient(BaseInAgentClient):
                                     except ValidationError as e:
                                         logging.error(e)
                                         logging.error(data["data"])
-                                    order = self.agent_client.api.get_order_details(orderId=upd.id)
+                                    order = self.api.get_order_details(orderId=upd.id)
                                     order = OrderFull.model_validate(order["result"])
                                     order_db = await models.Order.get_or_none(
                                         exid=order.id, ad__exid=order.itemId
-                                    ) or await self.agent_client.create_order(order)
+                                    ) or await self.create_order(order)
                                     match upd.status:
                                         case StatusApi.created:
                                             logging.info(f"Order {order.id} created at {order.createDate}")
@@ -108,10 +111,11 @@ class InAgentClient(BaseInAgentClient):
                                                 if not (pmacdx := await self.get_pma_by_cdex(order)):
                                                     continue
                                                 pma, cdx = pmacdx
-                                                am, tid = pma.check_in(
+                                                am, tid = await pma.check_in(
                                                     Decimal(order.amount),
                                                     cdx.cred.pmcur.cur.ticker,
-                                                    datetime.fromtimestamp(float(order.createDate) / 1000),
+                                                    # todo: почему в московском час.поясе?
+                                                    datetime.fromtimestamp(float(order.transferDate) / 1000),
                                                 )
                                                 if not tid:
                                                     logging.info(
@@ -135,44 +139,48 @@ class InAgentClient(BaseInAgentClient):
                                                     continue
 
                                                 # если висят незавершенные продажи с такой же суммой
-                                                pos = (await self.agent_client.get_orders_active(1))["result"]
+                                                pos = (await self.get_orders_active(1))["result"]
                                                 pos = [
                                                     o
                                                     for o in pos.get("items", [])
                                                     if (
                                                         o["amount"] == order.amount
                                                         and o["id"] != upd.id
-                                                        and int(order.createDate) < int(o["createDate"]) + 900 * 000
-                                                        # todo: get full_order from o, and cred or pm from full_order:
-                                                        # and o['paymentTermList'][0].accountNo == order.paymentTermList[0].accountNo
+                                                        and int(order.createDate)
+                                                        < int(o["createDate"]) + 15 * 60 * 1000
+                                                        # get full_order from o, and cred or pm from full_order:
+                                                        and self.api.get_order_details(orderId=o["id"])["result"][
+                                                            "paymentTermList"
+                                                        ][0]["accountNo"]
+                                                        == order.paymentTermList[0].accountNo
                                                     )
                                                 ]
                                                 curex = await models.CurEx.get(
-                                                    cur__ticker=order.currencyId, ex=self.agent_client.ex_client.ex
+                                                    cur__ticker=order.currencyId, ex=self.ex_client.ex
                                                 )
                                                 pos_db = await models.Order.filter(
                                                     exid__not=order.id,
                                                     cred_id=order_db.cred_id,
                                                     amount=int(float(order.amount) * 10**curex.scale),
                                                     status__not_in=[OrderStatus.completed, OrderStatus.canceled],
-                                                    created_at__gt=now() - timedelta(hours=1),
+                                                    created_at__gt=now() - timedelta(minutes=15),
                                                 )
                                                 if pos or pos_db:
-                                                    await self.agent_client.ex_client.bot.send(
+                                                    await self.ex_client.bot.send(
                                                         f"[Duplicate amount!]"
                                                         f"(https://www.bybit.com/ru-RU/p2p/orderList/{order.id})",
-                                                        self.agent_client.actor.person.user.username_id,
+                                                        self.actor.person.user.username_id,
                                                     )
                                                     logging.warning("Duplicate amount!")
                                                     continue
 
                                                 # !!! ОТПРАВЛЯЕМ ДЕНЬГИ !!!
-                                                self.agent_client.api.release_assets(orderId=upd.id)
+                                                self.api.release_assets(orderId=upd.id)
                                                 logging.info(
-                                                    f"Order {order.id} created, paid before #{tid}:{am} at {order.createDate}, and RELEASED at {datetime.now()}"
+                                                    f"Order {order.id} created, paid before #{tid}:{am} at {order.createDate}, and RELEASED at {now()}"
                                                 )
                                             elif upd.side == 1:  # я покупатель - ждем мою оплату
-                                                continue  # logging.warning(f"Order {order.id} PAID at {datetime.now()}: {int_am}")
+                                                continue  # logging.warning(f"Order {order.id} PAID at {now()}: {int_am}")
                                             else:
                                                 ...
                                             # todo: check is always canceling
@@ -231,14 +239,14 @@ class InAgentClient(BaseInAgentClient):
                                 case "RECEIVE":
                                     upd = Receive.model_validate(data["data"])
                                     if order_db := await models.Order.get_or_none(
-                                        exid=upd.orderId, ad__maker__ex=self.agent_client.actor.ex
+                                        exid=upd.orderId, ad__maker__ex=self.actor.ex
                                     ).prefetch_related("ad__pair_side__pair", "cred__pmcur__cur"):
-                                        im_taker = order_db.taker_id == self.agent_client.actor.id
+                                        im_taker = order_db.taker_id == self.actor.id
                                         im_buyer = order_db.ad.pair_side.is_sell == im_taker
                                         if order_db.ad.auto_msg != upd.message and upd.roleType == "user":
                                             msg, _ = await models.Msg.update_or_create(
                                                 {
-                                                    "to_maker": upd.userId == self.agent_client.actor.exid and im_taker,
+                                                    "to_maker": upd.userId == self.actor.exid and im_taker,
                                                     "sent_at": datetime.fromtimestamp(float(upd.createDate) / 1000),
                                                 },
                                                 txt=upd.message,
@@ -257,7 +265,7 @@ class InAgentClient(BaseInAgentClient):
                                     if upd.orderStatus in (
                                         StatusApi.wait_for_buyer,
                                     ):  # todo: тут приходит ордер.статус=10, хотя покупатель еще не нажал оплачено
-                                        order = self.agent_client.api.get_order_details(orderId=upd.orderId)["result"]
+                                        order = self.api.get_order_details(orderId=upd.orderId)["result"]
                                         order = OrderFull.model_validate(order)
 
                                 case "CLEAR":
@@ -290,15 +298,13 @@ class InAgentClient(BaseInAgentClient):
     async def money_upd(self, order_db: models.Order):
         # обновляем остаток монеты
         await order_db.fetch_related("ad__pair_side__pair", "cred", "transfer")
-        ass = await models.Asset.get(
-            addr__coin_id=order_db.ad.pair_side.pair.coin_id, addr__actor=self.agent_client.actor
-        )
+        ass = await models.Asset.get(addr__coin_id=order_db.ad.pair_side.pair.coin_id, addr__actor=self.actor)
         # обновляем остаток валюты
         fiat = await models.Fiat.get(
-            cred__person_id=self.agent_client.actor.person_id, cred__pmcur_id=order_db.cred.pmcur_id
+            cred__person_id=self.actor.person_id, cred__pmcur_id=order_db.cred.pmcur_id
         ).prefetch_related("cred__pmcur__pm")
         fee = round(order_db.amount * (fiat.cred.pmcur.pm.fee or 0) * 0.0001)
-        im_seller = order_db.ad.pair_side.is_sell == (_im_maker := order_db.ad.maker_id == self.agent_client.actor.id)
+        im_seller = order_db.ad.pair_side.is_sell == (_im_maker := order_db.ad.maker_id == self.actor.id)
         # k = int(im_seller) * 2 - 1  # im_seller: 1, im_buyer: -1
         if order_db.status == OrderStatus.created:
             if im_seller:
@@ -330,9 +336,9 @@ class InAgentClient(BaseInAgentClient):
         pma, cur = await self.get_pma_by_pmex(order_db)
         async with in_transaction():
             # отмечаем ордер на бирже "оплачен"
-            pmex = await models.PmEx.get(pm_id=order_db.cred.pmcur.pm_id, ex=self.agent_client.actor.ex)
-            credex = await models.CredEx.get(cred=order_db.cred, ex=self.agent_client.actor.ex)
-            self.agent_client.api.mark_as_paid(
+            pmex = await models.PmEx.get(pm_id=order_db.cred.pmcur.pmex_exid, ex=self.actor.ex)
+            credex = await models.CredEx.get(cred=order_db.cred, ex=self.actor.ex)
+            self.api.mark_as_paid(
                 orderId=str(order_db.exid),
                 paymentType=pmex.exid,  # pmex.exid
                 paymentId=str(credex.exid),  # credex.exid
@@ -341,7 +347,7 @@ class InAgentClient(BaseInAgentClient):
             if t := await models.Transfer.get_or_none(order=order_db, amount=order_db.amount):
                 await pma.bot.send(
                     f"Order# {order_db.exid}: Double send {fmt_am}{cur} to {order_db.cred.detail} #{t.pmid}!",
-                    self.agent_client.actor.person.user.username_id,
+                    self.actor.person.user.username_id,
                 )
                 raise Exception(
                     f"Order# {order_db.exid}: Double send {fmt_am}{cur} to {order_db.cred.detail} #{t.pmid}!"
@@ -362,38 +368,34 @@ class InAgentClient(BaseInAgentClient):
 
     async def send_receipt(self, oexid: str, tid: int) -> tuple[PmAgentClient | None, models.CredEx] | None:
         try:
-            if res := self.agent_client.api.upload_chat_file(upload_file=f"tmp/{tid}.png").get("result"):
+            if res := self.api.upload_chat_file(upload_file=f"tmp/{tid}.png").get("result"):
                 await sleep(0.5)
-                self.agent_client.api.send_chat_message(
-                    orderId=oexid, contentType="pic", message=res["url"], msgUuid=uuid4().hex
-                )
+                self.api.send_chat_message(orderId=oexid, contentType="pic", message=res["url"], msgUuid=uuid4().hex)
         except Exception as e:
             logging.error(e)
         await sleep(0.5)
-        self.agent_client.api.send_chat_message(
-            orderId=oexid, contentType="str", message=f"#{tid}", msgUuid=uuid4().hex
-        )
+        self.api.send_chat_message(orderId=oexid, contentType="str", message=f"#{tid}", msgUuid=uuid4().hex)
 
     async def get_pma_by_cdex(self, order: OrderFull) -> tuple[PmAgentClient | None, models.CredEx] | None:
         cdxs = await models.CredEx.filter(
-            ex=self.agent_client.ex_client.ex,
+            ex=self.ex_client.ex,
             exid__in=[ptl.id for ptl in order.paymentTermList],
-            cred__person=self.agent_client.actor.person,
+            cred__person=self.actor.person,
         ).prefetch_related("cred__pmcur__cur")
-        pmas = [pma for cdx in cdxs if (pma := self.pmacs.get(cdx.cred.pmcur.pm_id))]
+        pmas = [pma for cdx in cdxs if (pma := self.pmacs.get(cdx.cred.pmcur.pmex_exid))]
         if not len(pmas):
             # raise ValueError(order.paymentTermList, f"No pm_agents for {order.paymentTermList[0].paymentType}")
             return None
         elif len(pmas) > 1:
-            logging.error(order.paymentTermList, f">1 pm_agents for {cdxs[0].cred.pmcur.pm_id}")
+            logging.error(order.paymentTermList, f">1 pm_agents for {cdxs[0].cred.pmcur.pmex_exid}")
         else:
             return pmas[0], cdxs[0]
 
     async def get_pma_by_pmex(self, order_db: models.Order) -> tuple[PmAgentClient, str]:
-        pma = self.pmacs.get(order_db.cred.pmcur.pm_id)
+        pma = self.pmacs.get(order_db.cred.pmcur.pmex_exid)
         if pma:
             return pma, order_db.cred.pmcur.cur.ticker
-        logging.error(f"No pm_agents for {order_db.cred.pmcur.pm_id}")
+        logging.error(f"No pm_agents for {order_db.cred.pmcur.pmex_exid}")
 
     @staticmethod
     def listen(data: dict | None):
@@ -416,7 +418,7 @@ async def main():
             actor__person__user__status=UserStatus.ACTIVE,
             actor__person__user__pm_agents__isnull=False,
         )
-        .prefetch_related("actor__ex", "actor__person__user")
+        .prefetch_related("actor__ex", "actor__person__user__gmail")
         .first()
     )
     pm_agents = await models.PmAgent.filter(
@@ -434,13 +436,13 @@ async def main():
         # payeer_cl = Client(actor.person.user.username_id)
         for pma in pm_agents:
             pcl: PmAgentClient = pma.client(bbot)
-            cl.pmacs[pma.pm_id] = await pcl.start(await async_playwright().start(), True)
+            cl.pmacs[pma.pm_id] = await pcl.start(await async_playwright().start(), False)
         try:
             _ = await cl.start_listen()
         except Exception as e:
             await b.send("😱Bybit InAgent CRASHED!!!😱", agent.actor.person.user.username_id)
             await b.send(f"```\n{''.join(traceback.format_exception(e))}\n```", agent.actor.person.user.username_id)
-        await cl.agent_client.close()
+        await cl.close()
 
 
 if __name__ == "__main__":
