@@ -1,7 +1,7 @@
 from enum import StrEnum
 from typing import List, Optional, Any, Literal
-from pydantic import BaseModel, Field, field_serializer
-from xync_schema import xtype
+from pydantic import BaseModel, Field
+from xync_client.Bybit.etype.cred import MyPaymentTerm
 from xync_schema.xtype import BaseAd
 
 from xync_client.Abc.xtype import BaseAdUpdate
@@ -113,7 +113,7 @@ class Ad(BaseAd):
     recommend: bool = None  # for initial actualize
     recommendTag: str = None  # for initial actualize
     remark: str = Field(serialization_alias="auto_msg")
-    side: Literal[0, 1] = None  # for initial actualize  # 0 - покупка, 1 - продажа (для мейкера, т.е КАКАЯ объява)
+    side: Literal[0, 1] = None  # for initial actualize # 0 - покупка, 1 - продажа (для мейкера, т.е КАКАЯ объява)
     status: Literal[10, 20, 30]  # 10: online; 20: offline; 30: completed
     symbolInfo: SymbolInfo = None  # for initial actualize
     tokenId: str = None  # for initial actualize
@@ -126,59 +126,14 @@ class Ad(BaseAd):
     verificationOrderLabels: List[Any] = None  # for initial actualize
     verificationOrderSwitch: bool = None  # for initial actualize
     version: int = None  # for initial actualize
-    #
-    #
-    # class Ad(BaseAd):
-    #     accountId: str = None  # for initial actualize
-    #     authStatus: int = None  # for initial actualize
-    #     authTag: List[str] = None  # for initial actualize
-    #     ban: bool = None  # for initial actualize
-    #     baned: bool = None  # for initial actualize
-    #     blocked: str = None  # for initial actualize
-    #     createDate: str = None  # for initial actualize
-    #     currencyId: str = None  # for initial actualize
-    #     executedQuantity: str = None  # for initial actualize
-    #     fee: str = None  # for initial actualize
-    #     finishNum: int = None  # for initial actualize
-    #     frozenQuantity: str = None  # for initial actualize
-    #     exid: str = Field(serialization_alias="id")
-    #     isOnline: bool = None  # for initial actualize
-    #     itemType: str = None  # for initial actualize
-    #     lastLogoutTime: str = None  # for initial actualize
-    #     quantity: str = Field(serialization_alias="lastQuantity")
-    #     makerContact: bool = None  # for initial actualize
-    #     max_fiat: str = Field(serialization_alias="maxAmount")
-    #     min_fiat: str = Field(serialization_alias="minAmount")
-    #     nickName: str = None  # for initial actualize
-    #     orderNum: int = None  # for initial actualize
-    #     paymentPeriod: int = None  # for initial actualize
-    #     payments: List[str] = None  # for initial actualize
-    #     premium: str = None  # for initial actualize
-    #     price: str = None  # for initial actualize
-    #     priceType: Literal[0, 1] = None  # for initial actualize  # 0 - fix rate, 1 - floating
-    #     allQuantity: str = Field(serialization_alias="quantity")  # for initial actualize
-    #     recentExecuteRate: int = None  # for initial actualize
-    #     recentOrderNum: int = None  # for initial actualize
-    #     recommend: bool = None  # for initial actualize
-    #     recommendTag: str = None  # for initial actualize
-    #     auto_msg: str = Field(serialization_alias="remark")
-    #     is_sell: Literal[0, 1] = Field(serialization_alias="side")  # for initial actualize # 0 - покупка, 1 - продажа (для мейкера, т.е КАКАЯ объява)
-    #     status: Literal[10, 20, 30]  # 10: online; 20: offline; 30: completed
-    #     symbolInfo: SymbolInfo = None  # for initial actualize
-    #     tokenId: str = None  # for initial actualize
-    #     tokenName: str = None  # for initial actualize
-    #     tradingPreferenceSet: TradingPreferenceSet | None = None  # for initial actualize
-    #     userId: str = Field(serialization_alias="maker__exid")
-    #     userMaskId: str = None  # for initial actualize
-    #     userType: str = None  # for initial actualize
-    #     verificationOrderAmount: str = None  # for initial actualize
-    #     verificationOrderLabels: List[Any] = None  # for initial actualize
-    #     verificationOrderSwitch: bool = None  # for initial actualize
-    #     version: int = None  # for initial actualize
 
-    @field_serializer("status")
-    def status(self, status, _info) -> xtype.AdStatus:
-        return {10: xtype.AdStatus.active, 20: xtype.AdStatus.defActive, 30: xtype.AdStatus.soldOut}[status]
+    # @field_serializer("status")
+    # def status(self, status, _info) -> xtype.AdStatus:
+    #     return {10: xtype.AdStatus.active, 20: xtype.AdStatus.defActive, 30: xtype.AdStatus.soldOut}[status]
+
+
+class MyAd(Ad):
+    paymentTerms: List[MyPaymentTerm]
 
 
 class AdPostRequest(BaseModel):
