@@ -1,5 +1,3 @@
-from typing import Literal
-
 from pydantic import BaseModel
 
 from xync_client.Abc.xtype import CredExOut
@@ -15,18 +13,31 @@ class PaymentItem(BaseModel):
     required: bool
 
 
-class PaymentConfigVo(BaseModel):
-    paymentType: str
+class BasePaymentConf(BaseModel):
+    paymentType: int
+    paymentName: str
+
+
+class PaymentConfig(BasePaymentConf):
+    class PaymentTemplateItem(BaseModel):
+        labelDialect: str
+        placeholderDialect: str
+        fieldName: str
+
+    paymentDialect: str
+    paymentTemplateItem: list[PaymentTemplateItem]
+
+
+class PaymentConfigVo(BasePaymentConf):
     checkType: int
     sort: int
-    paymentName: str
     addTips: str
     itemTips: str
-    online: Literal[0, 1]  # Non-balance coin purchase (0 Offline), balance coin purchase (1 Online)
-    items: list[PaymentItem]
+    online: int
+    items: list[dict[str, str | bool]]
 
 
-class CredEpyd(CredExOut):
+class PaymentTerm(CredExOut):
     id: str  # int
     realName: str
     paymentType: int  # int
@@ -44,7 +55,7 @@ class CredEpyd(CredExOut):
     mobile: str
     businessName: str
     concept: str
-    online: str
+    online: str = None
     paymentExt1: str
     paymentExt2: str
     paymentExt3: str
@@ -54,6 +65,15 @@ class CredEpyd(CredExOut):
     paymentTemplateVersion: int
 
 
+class MyPaymentTerm(PaymentTerm):
+    paymentConfig: PaymentConfig
+    realNameVerified: bool
+
+
+class CredEpyd(PaymentTerm):
+    securityRiskToken: str = ""
+
+
 class MyCredEpyd(CredEpyd):  # todo: заменить везде где надо CredEpyd -> MyCredEpyd
     countNo: str
     hasPaymentTemplateChanged: bool
