@@ -2,8 +2,10 @@ import json
 from asyncio import run
 
 from pyro_client.client.file import FileClient
+from x_client import df_hdrs
 from x_model import init_db
 from xync_schema import models, xtype
+from xync_schema.enums import AdStatus
 from xync_schema.models import Ex, Agent
 
 from xync_client.Abc.Ex import BaseExClient
@@ -14,7 +16,8 @@ from xync_client.loader import TORM
 
 
 class ExClient(BaseExClient):  # Bybit client
-    headers = {"cookie": ";"}  # rewrite token for public methods
+    host = "api2.bybit.com"
+    headers = df_hdrs  # rewrite token for public methods
     agent: Agent = None
 
     async def _get_auth_cks(self) -> dict[str, str]:
@@ -22,6 +25,14 @@ class ExClient(BaseExClient):  # Bybit client
             self.agent = await Agent.get(actor__ex=self.ex).prefetch_related("actor")
         return self.agent.auth["cookies"]
 
+    @staticmethod
+    def ad_status(status: int) -> AdStatus:
+        return {
+            10: AdStatus.active,
+            20: AdStatus.defActive,
+            30: AdStatus.soldOut,
+        }[status]
+
     async def _get_config(self):
         resp = await self._get("/fiat/p2p/config/initial")
         return resp["result"]  # todo: tokens, pairs, ...
