@@ -46,7 +46,7 @@ class AgentClient(BaseAgentClient):
 
     async def cred_new(self, cred: models.Cred) -> models.CredEx:
         pmcur = await cred.pmcur
-        exid = str(await models.PmEx.get(pm_id=pmcur.pm_id, ex=self.ex_client.ex).values_list("exid", flat=True))
+        exid = str(await models.PmEx.get(pm_id=pmcur.pmex_exid, ex=self.ex_client.ex).values_list("exid", flat=True))
         field_map = {
             "payee": "name",
             "bank": "extra",
@@ -71,7 +71,7 @@ class AgentClient(BaseAgentClient):
 
     async def cred_upd(self, cred: models.Cred, exid: int) -> models.CredEx:
         pmcur = await cred.pmcur
-        _exid = str(await models.PmEx.get(pm_id=pmcur.pm_id, ex=self.ex_client.ex).values_list("exid", flat=True))
+        _exid = str(await models.PmEx.get(pm_id=pmcur.pmex_exid, ex=self.ex_client.ex).values_list("exid", flat=True))
         field_map = {
             "payee": "name",
             "bank": "extra",
