@@ -1,7 +1,7 @@
 from asyncio import run
 
 from pyro_client.client.file import FileClient
-from pyro_client.loader import TOKEN
+from pyro_client.loader import NET_TOKEN
 from x_model import init_db
 
 from xync_client.Abc.Exception import NoPairOnEx
@@ -102,7 +102,7 @@ class ExClient(BaseExClient):
 async def main():
     _ = await init_db(TORM)
     bg = await models.Ex.get(name="Okx")
-    cl = ExClient(bg, FileClient(TOKEN))
+    cl = ExClient(bg, FileClient(NET_TOKEN))
     await cl.ads("USDT", "EUR", True)
     # curs = await cl.curs()
     # coins = await cl.coins()
