@@ -22,6 +22,7 @@ from playwright.async_api import async_playwright, Playwright, Error
 
 # noinspection PyProtectedMember
 from playwright._impl._errors import TimeoutError
+from tortoise.timezone import now
 from xync_bot import XyncBot
 from xync_schema.models import TopUp, TopUpAble, PmAgent, Transfer
 
@@ -139,7 +140,7 @@ class Client(PmAgentClient):
     async def send(self, t: Transfer) -> tuple[str, bytes] | float:
         dest, cur = t.order.cred.detail, t.order.cred.pmcur.cur.ticker
         amount = round(t.order.amount * 10**-t.order.cred.pmcur.cur.scale, t.order.cred.pmcur.cur.scale)
-        self.last_active = datetime.now()
+        self.last_active = now()
         page = self.page
         if not page.url.startswith(self.pages.SEND):
             try:
@@ -181,7 +182,7 @@ class Client(PmAgentClient):
                 await page.click(f".history-id-{trans_num} a.link")
                 sleep(1)
                 receipt = await page.query_selector(".ui-dialog.ui-corner-all")
-                return trans_num, await receipt.screenshot(path=f"tmp/{trans_num}.png")
+                return trans_num, receipt and await receipt.screenshot(path=f"tmp/{trans_num}.png")
             else:
                 await self.receive("Payeer хз", photo=await self.page.screenshot())
                 return -1
@@ -192,10 +193,10 @@ class Client(PmAgentClient):
             )
             return has_amount
 
-    def check_in(
+    async def check_in(
         self, amount: Decimal | int | float, cur: str, dt: datetime = None, tid: str | int = None
     ) -> tuple[Decimal | None, int | None]:
-        history = self.api.history(type="incoming", append=tid, count=3)
+        history = self.api.history(type="incoming", count=10)
         if tid:
             return (t := history.get(tid)) and Decimal(t["creditedAmount"])
         ts: list[dict] = [
@@ -204,7 +205,8 @@ class Client(PmAgentClient):
             if (
                 amount <= Decimal(h["creditedAmount"]) <= ceil(amount)
                 and h["creditedCurrency"] == cur
-                and datetime.fromisoformat(h["date"]) > dt - timedelta(minutes=1)
+                # todo: wrong tz
+                and datetime.fromisoformat(h["date"]) > dt - timedelta(minutes=3)  # +180(tz)-5
             )
         ]
         if not (t := ts and ts[0]):
