@@ -174,7 +174,7 @@ class Client(PmAgentClient):
         elif self.agent.user.username.session:
             if not (code := await self.wait_for_code(volet_bot_id, topic, hg)):
                 if 1:  # todo: Is mail_confirm required?
-                    if _mcr := await self.gmail.mail_confirm(amount, t.updated_at):
+                    if _mcr := await self.gmail.volet_confirm(amount, t.updated_at):
                         ...
                         # todo: click Continue
                     if not (code := await self.wait_for_code(volet_bot_id, topic, hg)):
@@ -273,7 +273,7 @@ async def _test():
         pma = await models.PmAgent.get(
             active=True,
             auth__isnull=False,
-            pm_id=o.cred.pmcur.pm_id,
+            pm_id=o.cred.pmcur.pmex_exid,
             user__person__actors=o.ad.maker_id,
             user__status=UserStatus.ACTIVE,
         ).prefetch_related("pm", "user__gmail", "user__username__session")
