@@ -88,16 +88,17 @@ class APIClient:
     async def check_by_amount(self, amount: decimal, cur: str = "RUB", timeout: int = 5 * 60, past: int = 0):
         hist: list = self.make_request("history", {"transactionDirection": "INCOMING", "count": 3, "from": 0})
         if int(hist[0].amount) == int(amount):
-            return hist[0]
+            return hist[0]["amount"], hist[0]["id"]
         await sleep(period)
         past += period
         if past < timeout:
             return await self.check_by_amount(amount, cur, timeout, past)
-        return False
+        return None, None
 
     def check_by_id(self, tid: str):
-        t: dict = self.make_request("findTransaction", tid)
-        return t
+        if t := self.make_request("findTransaction", tid):
+            return t["amount"], t["id"]
+        return None, None
 
 
 async def main():
